<?php
$TRANSLATIONS = array(
"The php-json module is needed by the many applications for inter communications" => "Modulen php-jason blir benyttet til inter kommunikasjon",
"The php-curl module is needed to fetch the page title when adding a bookmark" => "Modulen \"php-curl\" er nødvendig for å hente sidetittelen når du legger til et bokmerke",
"The php-gd module is needed to create thumbnails of your images" => "Modulen php-gd blir benyttet til å lage miniatyr av bildene dine",
"The php-ldap module is needed connect to your ldap server" => "Modulen php-ldap benyttes for å koble til din ldapserver",
"The php-zip module is needed download multiple files at once" => "Modulen php-zup benyttes til å laste ned flere filer på en gang.",
"The php-mb_multibyte module is needed to manage correctly the encoding." => "Modulen php-mb_multibyte benyttes til å håndtere korrekt tegnkoding.",
"The php-ctype module is needed validate data." => "Modulen php-ctype benyttes til å validere data.",
"The php-xml module is needed to share files with webdav." => "Modulen php-xml benyttes til å dele filer med webdav",
"The allow_url_fopen directive of your php.ini should be set to 1 to retrieve knowledge base from OCS servers" => "Direktivet allow_url_fopen i php.ini bør settes til 1 for å kunne hente kunnskapsbasen fra OCS-servere",
"The php-pdo module is needed to store owncloud data into a database." => "Modulen php-pdo benyttes til å lagre ownCloud data i en database.",
"The iconv module is needed to convert data into the correct charset." => "Modulen \"iconv\" er nødvendig for å konvertere dataene til korrekt tegnsett.",
"Dependencies status" => "Avhengighetsstatus",
"Used by :" => "Benyttes av:"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
